You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@spark.apache.org by "Carson Wang (JIRA)" <ji...@apache.org> on 2016/02/05 08:08:39 UTC

[jira] [Updated] (SPARK-13185) Improve the performance of DateTimeUtils by reusing Calendar objects

     [ https://issues.apache.org/jira/browse/SPARK-13185?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]

Carson Wang updated SPARK-13185:
--------------------------------
    Summary: Improve the performance of DateTimeUtils by reusing Calendar objects  (was: Improve the performance of DateTimeUtils by reusing TimeZone and Calendar objects)

> Improve the performance of DateTimeUtils by reusing Calendar objects
> --------------------------------------------------------------------
>
>                 Key: SPARK-13185
>                 URL: https://issues.apache.org/jira/browse/SPARK-13185
>             Project: Spark
>          Issue Type: Improvement
>          Components: SQL
>    Affects Versions: 1.6.0
>            Reporter: Carson Wang
>            Priority: Minor
>
> It is expensive to create java TimeZone and Calendar objects in each method of DateTimeUtils. We can reuse the objects to improve the performance. In one of my Sql queries which calls StringToDate many times, the duration of the stage improved from 1.6 minutes to 1.2 minutes.



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

---------------------------------------------------------------------
To unsubscribe, e-mail: issues-unsubscribe@spark.apache.org
For additional commands, e-mail: issues-help@spark.apache.org